@@ -1,4 +1,8 @@
 from connection import ClientConnection
+try:
+    from tcpyconfig import REQUEST_TIMEOUT
+except:
+    from default import REQUEST_TIMEOUT
 from default import SERVER_DEFAULT, PORT_DEFAULT
 from util import to_int
 
@@ -11,10 +15,10 @@ class TCPClient(object):
     def __init__(self, host=SERVER_DEFAULT, port=PORT_DEFAULT):
         self.host = host
         self.port = to_int(port)
-        self._conn = ClientConnection(self.host, self.port)
+        self._conn = ClientConnection(self.host, self.port, timeout=REQUEST_TIMEOUT)
 
     def connect(self):
-        self._conn.connect()
+        self._conn._connect()
 
     def send(self, data):
         self._conn.send(data)
@@ -23,7 +27,7 @@ class TCPClient(object):
         return self._conn.read()
 
     def disconnect(self):
-        self._conn.finish()
+        self._conn._disconnect()
 
     def execute(self, cmd, **params):
         params['cmd'] = cmd
