@@ -1,7 +1,8 @@
 SERVER_DEFAULT = "localhost"
 PORT_DEFAULT = 7272
 
+REQUEST_TIMEOUT = None
+
 NUM_THREADS = 4
-POLL_INTERVAL = 0.001
 
 DEBUG = False
